import hljs from 'highlight.js';
import MarkdownIt from 'markdown-it';
import 'highlight.js/styles/github.css';
export function posToOffset(doc, pos) {
  if (pos.line >= doc.lines) {
    return;
  }
  var offset = doc.line(pos.line + 1).from + pos.character;
  if (offset > doc.length) {
    return;
  }
  return offset;
}
export function offsetToPos(doc, offset) {
  var line = doc.lineAt(offset);
  return {
    line: line.number - 1,
    character: offset - line.from
  };
}
export function formatContents(contents) {
  if (Array.isArray(contents)) {
    return contents.map(function (c) {
      return formatContents(c) + '\n\n';
    }).join('');
  } else if (typeof contents === 'string') {
    return contents;
  } else {
    return contents.value;
  }
}
export var renderMarkdownContent = function renderMarkdownContent(val) {
  var render = new MarkdownIt({
    html: true,
    linkify: true,
    breaks: true,
    highlight: function highlight(str, lang) {
      if (lang && hljs.getLanguage(lang)) {
        try {
          var hl = hljs.highlight(lang, str).value;
          return hl;
        } catch (__) {
          //
        }
      }
      return ''; // use external default escaping
    }
  });
  return render.render(val);
};
export var renderMarkupContent = function renderMarkupContent(contents) {
  var dom = document.createElement('div');
  dom.classList.add('documentation');
  var res = renderMarkdownContent(formatContents(contents));
  dom.innerHTML = res;
  return dom;
};